@@ -22,7 +22,7 @@ class DbUserGroupBackend extends DbRepository implements Inspectable, UserGroupB
     protected $queryColumns = array(
         'group' => array(
             'group_id'      => 'g.id',
-            'group'         => 'g.name COLLATE utf8_general_ci',
+            'group'         => 'g.name COLLATE utf8mb4_general_ci',
             'group_name'    => 'g.name',
             'parent'        => 'g.parent',
             'created_at'    => 'UNIX_TIMESTAMP(g.ctime)',
@@ -30,7 +30,7 @@ class DbUserGroupBackend extends DbRepository implements Inspectable, UserGroupB
         ),
         'group_membership' => array(
             'group_id'      => 'gm.group_id',
-            'user'          => 'gm.username COLLATE utf8_general_ci',
+            'user'          => 'gm.username COLLATE utf8mb4_general_ci',
             'user_name'     => 'gm.username',
             'created_at'    => 'UNIX_TIMESTAMP(gm.ctime)',
             'last_modified' => 'UNIX_TIMESTAMP(gm.mtime)'
@@ -133,7 +133,7 @@ class DbUserGroupBackend extends DbRepository implements Inspectable, UserGroupB
      * @param   string  $table
      * @param   array   $bind
      */
-    public function insert($table, array $bind)
+    public function insert($table, array $bind, array $types = array())
     {
         $bind['created_at'] = date('Y-m-d H:i:s');
         parent::insert($table, $bind);
@@ -146,7 +146,7 @@ class DbUserGroupBackend extends DbRepository implements Inspectable, UserGroupB
      * @param   array   $bind
      * @param   Filter  $filter
      */
-    public function update($table, array $bind, Filter $filter = null)
+    public function update($table, array $bind, Filter $filter = null, array $types = array())
     {
         $bind['last_modified'] = date('Y-m-d H:i:s');
         parent::update($table, $bind, $filter);
@@ -271,7 +271,7 @@ class DbUserGroupBackend extends DbRepository implements Inspectable, UserGroupB
      */
     protected function persistGroupId($groupName)
     {
-        if (! $groupName || empty($groupName) || is_numeric($groupName)) {
+        if (empty($groupName) || is_numeric($groupName)) {
             return $groupName;
         }
 
