@@ -175,7 +175,6 @@ class BackendConfigForm extends ConfigForm
             'checkbox',
             'disabled',
             array(
-                'required'  => true,
                 'label'     => $this->translate('Disable This Backend')
             )
         );
@@ -216,8 +215,6 @@ class BackendConfigForm extends ConfigForm
             )
         );
 
-        $decorators = static::$defaultElementDecorators;
-        array_pop($decorators); // Removes the HtmlTag decorator
         $this->addElement(
             'select',
             'resource',
@@ -227,7 +224,6 @@ class BackendConfigForm extends ConfigForm
                 'description'   => $this->translate('The resource to use'),
                 'multiOptions'  => $this->resources[$resourceType],
                 'value'         => current($this->resources[$resourceType]),
-                'decorators'    => $decorators,
                 'autosubmit'    => true
             )
         );
@@ -237,7 +233,6 @@ class BackendConfigForm extends ConfigForm
             'resource_note',
             array(
                 'escape'        => false,
-                'decorators'    => $decorators,
                 'value'         => sprintf(
                     '<a href="%1$s" data-base-target="_next" title="%2$s" aria-label="%2$s">%3$s</a>',
                     $this->getView()->url('config/editresource', array('resource' => $resourceName)),
@@ -246,16 +241,6 @@ class BackendConfigForm extends ConfigForm
                 )
             )
         );
-        $this->addDisplayGroup(
-            array('resource', 'resource_note'),
-            'resource-group',
-            array(
-                'decorators'    => array(
-                    'FormElements',
-                    array('HtmlTag', array('tag' => 'div', 'class' => 'control-group'))
-                )
-            )
-        );
 
         if (isset($formData['skip_validation']) && $formData['skip_validation']) {
             // In case another error occured and the checkbox was displayed before
@@ -290,7 +275,10 @@ class BackendConfigForm extends ConfigForm
 
         if (($el = $this->getElement('skip_validation')) === null || false === $el->isChecked()) {
             $resourceConfig = ResourceFactory::getResourceConfig($this->getValue('resource'));
-            if (! self::isValidIdoSchema($this, $resourceConfig) || !self::isValidIdoInstance($this, $resourceConfig)) {
+            if (! self::isValidIdoSchema($this, $resourceConfig)
+                || (! $this->getElement('disabled')->isChecked()
+                    && ! self::isValidIdoInstance($this, $resourceConfig))
+            ) {
                 if ($el === null) {
                     $this->addSkipValidationCheckbox();
                 }
@@ -313,7 +301,6 @@ class BackendConfigForm extends ConfigForm
             array(
                 'order'         => 0,
                 'ignore'        => true,
-                'required'      => true,
                 'label'         => $this->translate('Skip Validation'),
                 'description'   => $this->translate(
                     'Check this to not to validate the IDO schema of the chosen resource.'
