@@ -5,6 +5,7 @@ namespace Icinga\Module\Setup\Forms;
 
 use Exception;
 use Icinga\Application\Config;
+use Icinga\Authentication\User\ExternalBackend;
 use Icinga\Authentication\User\UserBackend;
 use Icinga\Authentication\User\DbUserBackend;
 use Icinga\Authentication\User\LdapUserBackend;
@@ -14,6 +15,7 @@ use Icinga\Data\ConfigObject;
 use Icinga\Data\ResourceFactory;
 use Icinga\Data\Selectable;
 use Icinga\Exception\NotImplementedError;
+use Icinga\Protocol\Ldap\LdapQuery;
 use Icinga\Web\Form;
 
 /**
@@ -99,6 +101,7 @@ class AdminAccountPage extends Form
     public function createElements(array $formData)
     {
         $choices = array();
+        $groups = [];
         if ($this->backendConfig['backend'] !== 'db') {
             $choices['by_name'] = $this->translate('By Name', 'setup.admin');
             $choice = isset($formData['user_type']) ? $formData['user_type'] : 'by_name';
@@ -114,6 +117,7 @@ class AdminAccountPage extends Form
             $choice = isset($formData['user_type']) ? $formData['user_type'] : 'new_user';
         }
 
+        $users = [];
         if (in_array($this->backendConfig['backend'], array('db', 'ldap', 'msldap'))) {
             $users = $this->fetchUsers();
             if (! empty($users)) {
@@ -220,7 +224,8 @@ class AdminAccountPage extends Form
                     'label'             => $this->translate('Password'),
                     'description'       => $this->translate(
                         'Enter the password to assign to the newly created account.'
-                    )
+                    ),
+                    'autocomplete'      => 'new-password'
                 )
             );
             $this->addElement(
@@ -269,8 +274,8 @@ class AdminAccountPage extends Form
      */
     protected function getUsername()
     {
-        $name = getenv('REMOTE_USER');
-        if ($name === false) {
+        list($name, $_) = ExternalBackend::getRemoteUserInformation();
+        if ($name === null) {
             return '';
         }
 
@@ -296,7 +301,8 @@ class AdminAccountPage extends Form
                 ->select(array('user_name'))
                 ->order('user_name', 'asc', true);
             if (in_array($this->backendConfig['backend'], array('ldap', 'msldap'))) {
-                $query->getQuery()->setUsePagedResults();
+                /** @var LdapQuery $query */
+                $query->setUsePagedResults();
             }
 
             return $query->fetchColumn();
@@ -354,7 +360,8 @@ class AdminAccountPage extends Form
                 ->createUserGroupBackend()
                 ->select(array('group_name'));
             if (in_array($this->backendConfig['backend'], array('ldap', 'msldap'))) {
-                $query->getQuery()->setUsePagedResults();
+                /** @var LdapQuery $query */
+                $query->setUsePagedResults();
             }
 
             return $query->fetchColumn();
