@@ -6,6 +6,7 @@ namespace Icinga\Module\Setup\Utils;
 use PDO;
 use PDOException;
 use LogicException;
+use Zend_Db_Adapter_Pdo_Abstract;
 use Zend_Db_Adapter_Pdo_Mysql;
 use Zend_Db_Adapter_Pdo_Pgsql;
 use Icinga\Util\File;
@@ -121,6 +122,12 @@ class DbTool
      */
     public function __construct(array $config)
     {
+        if (! isset($config['port'])) {
+            // TODO: This is not quite correct, but works as it previously did. Previously empty values were not
+            //       transformed no NULL (now they are) so if the port is now null, it's been the empty string.
+            $config['port'] = '';
+        }
+
         $this->config = $config;
     }
 
@@ -280,6 +287,11 @@ class DbTool
                 if ($this->config['ssl_cipher']) {
                     $config['driver_options'][PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
                 }
+                if (defined('PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT')
+                    && $this->config['ssl_do_not_verify_server_cert']
+                ) {
+                    $config['driver_options'][PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT] = false;
+                }
             }
             $this->zendConn = new Zend_Db_Adapter_Pdo_Mysql($config);
         } elseif ($this->config['db'] === 'pgsql') {
@@ -330,6 +342,11 @@ class DbTool
             if ($this->config['ssl_cipher']) {
                 $driverOptions[PDO::MYSQL_ATTR_SSL_CIPHER] = $this->config['ssl_cipher'];
             }
+            if (defined('PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT')
+                && $this->config['ssl_do_not_verify_server_cert']
+            ) {
+                $driverOptions[PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT] = false;
+            }
         }
 
         $this->pdoConn = new PDO(
@@ -541,7 +558,7 @@ class DbTool
      * @param   string  $username       The login name for which to check the privileges,
      *                                  if NULL the current login is used
      *
-     * @return  bool
+     * @return  ?bool
      */
     public function checkPrivileges(array $privileges, array $context = null, $username = null)
     {
@@ -557,7 +574,7 @@ class DbTool
      *
      * @param   array   $privileges     The privileges that should be grantable
      *
-     * @return  bool
+     * @return  ?bool
      */
     public function isGrantable($privileges)
     {
@@ -663,7 +680,7 @@ class DbTool
      *
      * @param   string  $username   The username to search
      *
-     * @return  bool
+     * @return  ?bool
      */
     public function hasLogin($username)
     {
